// 运行环境
const envConfig = require('dotenv').config({
  path: `.env${process.env.ENV ? `.${process.env.ENV}` : ''}`,
})

export default {
  router: {
    middleware: 'auth',
  },

  // Global page headers: https://go.nuxtjs.dev/config-head
  head: {
    title: '认证通',
    htmlAttrs: {
      lang: 'zh-cn',
    },
    meta: [
      { charset: 'utf-8' },
      { name: 'viewport', content: 'width=device-width, initial-scale=1' },
      { name: 'description', content: '认证通|一款专业的正品认证SaaS软件系统' },
      { name: 'format-detection', content: 'telephone=no' },
    ],
    // link: [{ rel: 'icon', type: 'image/x-icon', href: '/favicon.ico' }],
    script: [
      {
        src: '/map.config.js',
      },
      {
        src: 'https://webapi.amap.com/maps?v=2.0&key=eae3be059db26dc1f9cae1d1bee9d4cb',
      },
    ],
  },

  // Global CSS: https://go.nuxtjs.dev/config-css
  css: [
    'vant/lib/index.css',
    'element-ui/lib/theme-chalk/index.css',
    'swiper/css/swiper.css',
    '@/styles/global.css',
  ],

  // Plugins to run before rendering page: https://go.nuxtjs.dev/config-plugins
  plugins: [
    '@/plugins/vant',
    '@/plugins/element-ui',
    '@/plugins/axios',
    '@/plugins/vue-filters',
    '@/plugins/storage',
  ],

  // Auto import components: https://go.nuxtjs.dev/config-components
  components: true,

  // Modules for dev and build (recommended): https://go.nuxtjs.dev/config-modules
  buildModules: [
    '@nuxtjs/style-resources',
    // https://go.nuxtjs.dev/tailwindcss
    '@nuxtjs/tailwindcss',
  ],

  // Modules: https://go.nuxtjs.dev/config-modules
  modules: [
    // https://go.nuxtjs.dev/axios
    '@nuxtjs/axios',
  ],

  // Axios module configuration: https://go.nuxtjs.dev/config-axios
  axios: {
    // Workaround to avoid enforcing hard-coded localhost:3000: https://github.com/nuxt-community/axios-module/issues/308
    baseURL: envConfig.parsed.BASE_URL,
  },

  // Build Configuration: https://go.nuxtjs.dev/config-build
  build: {
    extractCSS: true,
    filenames: {
      chunk: ({ isDev }) => (isDev ? '[name].js' : '[id].[contenthash].js'),
    },
    styleResources: {
      scss: './themes/themeMixin.scss',
    },
  },

  // 配置 Nuxt.js 应用是开发模式还是生产模式
  dev: process.env.NODE_ENV !== 'production',

  // 配置在客户端和服务端共享的环境变量
  env: {
    ...process.env,
    ...envConfig.parsed,
  },

  server: {
    port: process.env.PORT,
    host: process.env.HOST,
  },
}
